@@ -61,9 +61,10 @@ FILE *_read_jpeg(const char *filename,
   // open file
   FILE *fp;
   if ((fp = fopen(filename, "rb")) == NULL) {
-    //fprintf(stderr, "can't open %s\n", filename);
+    fprintf(stderr, "not possible to open\n");
     return NULL;
   }
+  
   // check file size
   fseek(fp, 0L, SEEK_END);
   size_t fsize = ftell(fp);
@@ -208,9 +209,7 @@ int read_jpeg_dct(
   struct jpeg_error_mgr jerr;
   // read jpeg header
   FILE *fp;
-  if((fp = _read_jpeg(srcfile, &cinfo, &jerr, FALSE)) == NULL) return 0;
-  // TODO: read markers
-  (void) jpeg_read_header(&cinfo, TRUE);
+  if((fp = _read_jpeg(srcfile, &cinfo, &jerr, TRUE)) == NULL) return 0;
   // read DCT
   jvirt_barray_ptr *coeffs_array = jpeg_read_coefficients(&cinfo);
   // read dct
@@ -531,9 +530,9 @@ int read_jpeg_spatial(
 
   if (overwrite_flag(flags, DO_FANCY_UPSAMPLING)) {
     cinfo.do_fancy_upsampling = flag_is_set(flags, DO_FANCY_UPSAMPLING);
-    #if JPEG_LIB_VERSION >= 70
-    fprintf(stderr, "- read %s: DO_FANCY_UPSAMPLING %d min_DCT_h_scaled_size %d max_DCT_h_scaled_size %d\n", srcfile, cinfo.do_fancy_upsampling, cinfo.min_DCT_h_scaled_size, cinfo.min_DCT_h_scaled_size);
-    #endif
+    // #if JPEG_LIB_VERSION >= 70
+    // fprintf(stderr, "- read %s: DO_FANCY_UPSAMPLING %d min_DCT_h_scaled_size %d max_DCT_h_scaled_size %d\n", srcfile, cinfo.do_fancy_upsampling, cinfo.min_DCT_h_scaled_size, cinfo.min_DCT_h_scaled_size);
+    // #endif
   }
   if (overwrite_flag(flags, DO_BLOCK_SMOOTHING))
     cinfo.do_block_smoothing  = flag_is_set(flags, DO_BLOCK_SMOOTHING);
