@@ -32,8 +32,9 @@ class DCTJPEG(_jpeg.JPEG):
         return (((ctypes.c_short * 64) * self.width_in_blocks(i)) * self.height_in_blocks(i))()
     def read_dct(self):
         # write content into temporary file
-        tmp = tempfile.NamedTemporaryFile(suffix='jpeg')
+        tmp = tempfile.NamedTemporaryFile(suffix='.jpeg')
         tmp.write(self.content)
+        tmp.flush()
         # allocate DCT components
         Y = self._alloc_dct_component(0)
         Cb,Cr = None,None
@@ -47,7 +48,7 @@ class DCTJPEG(_jpeg.JPEG):
             Y           = Y,
             Cb          = Cb,
             Cr          = Cr,
-            qt          = qt
+            qt          = qt,
         )
         # close temporary file
         # process
